@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2017 -- leonerd@leonerd.org.uk
 
 package Tickit::ContainerWidget;
 
@@ -12,7 +12,7 @@ use feature qw( switch );
 use base qw( Tickit::Widget );
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 use Carp;
 
@@ -181,7 +181,10 @@ sub window_lost
 {
    my $self = shift;
 
-   $_->set_window( undef ) for $self->children;
+   foreach my $child ( $self->children ) {
+      $child->window->close;
+      $child->set_window( undef );
+   }
 
    $self->SUPER::window_lost( @_ );
 }
